"""The Quantitative Imaging Profile (*QuIP*) REST server."""

__version__ = '5.7.2'
"""
The one-based major.minor.patch version based on the
`Fast and Loose Versioning <https://gist.github.com/FredLoney/6d946112e0b0f2fc4b57>`_
scheme. Minor and patch version numbers begin at 1.
"""
